/*
    LogExport: Export Symbian call log to a file
	Copyright (C) 2007 Yohanes Nugroho

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
/*
============================================================================
 Name        : LogExportAppView.h
 Author      : Yohanes Nugroho
 Copyright   : Yohanes Nugroho
 Description : Declares view class for application.
============================================================================
*/

#ifndef __LOGEXPORTAPPVIEW_h__
#define __LOGEXPORTAPPVIEW_h__

// INCLUDES
#include <coecntrl.h>
#include <txtrich.h>
#include <FRMTLAY.H>
#include <FRMTVIEW.H>


class CLogClient;
class CLogEvent;
class CLogFilter;
class CLogViewEvent;
class CCallArray;
class MCallLogEngineObserver;
class CAddEntries;


// CLASS DECLARATION
class CLogExportAppView : public CCoeControl
    {
    public: // New methods

        /**
        * NewL.
        * Two-phased constructor.
        * Create a CLogExportAppView object, which will draw itself to aRect.
        * @param aRect The rectangle this view will be drawn to.
        * @return a pointer to the created instance of CLogExportAppView.
        */
        static CLogExportAppView* NewL( const TRect& aRect );

        /**
        * NewLC.
        * Two-phased constructor.
        * Create a CLogExportAppView object, which will draw itself
        * to aRect.
        * @param aRect Rectangle this view will be drawn to.
        * @return A pointer to the created instance of CLogExportAppView.
        */
        static CLogExportAppView* NewLC( const TRect& aRect );

        /**
        * ~CLogExportAppView
        * Virtual Destructor.
        */
        virtual ~CLogExportAppView();

    public:  // Functions from base classes

        /**
        * From CCoeControl, Draw
        * Draw this CLogExportAppView to the screen.
        * @param aRect the rectangle of this view that needs updating
        */
        void Draw( const TRect& aRect ) const;

        /**
        * From CoeControl, SizeChanged.
        * Called by framework when the view size is changed.
        */
        virtual void SizeChanged();

    private: // Constructors

        /**
        * ConstructL
        * 2nd phase constructor.
        * Perform the second phase construction of a
        * CLogExportAppView object.
        * @param aRect The rectangle this view will be drawn to.
        */
        void ConstructL(const TRect& aRect);

        /**
        * CLogExportAppView.
        * C++ default constructor.
        */
        CLogExportAppView();
		
	CTextLayout* iLayout; // text layout
    CTextView* iTextView; // text view
    CParaFormatLayer* iParaFormatLayer;
    CCharFormatLayer* iCharFormatLayer;
    CRichText* iRichText; 
		

    };

#endif // __LOGEXPORTAPPVIEW_h__

// End of File
