/*
    LogExport: Export Symbian call log to a file
	Copyright (C) 2007 Yohanes Nugroho

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
/*
============================================================================
 Name        : LogExportDocument.h
 Author      : Yohanes Nugroho
 Copyright   : Yohanes Nugroho
 Description : Declares document class for application.
============================================================================
*/

#ifndef __LOGEXPORTDOCUMENT_h__
#define __LOGEXPORTDOCUMENT_h__

// INCLUDES
#include <akndoc.h>

// FORWARD DECLARATIONS
class CLogExportAppUi;
class CEikApplication;


// CLASS DECLARATION

/**
* CLogExportDocument application class.
* An instance of class CLogExportDocument is the Document part of the
* AVKON application framework for the LogExport example application.
*/
class CLogExportDocument : public CAknDocument
    {
    public: // Constructors and destructor

        /**
        * NewL.
        * Two-phased constructor.
        * Construct a CLogExportDocument for the AVKON application aApp
        * using two phase construction, and return a pointer
        * to the created object.
        * @param aApp Application creating this document.
        * @return A pointer to the created instance of CLogExportDocument.
        */
        static CLogExportDocument* NewL( CEikApplication& aApp );

        /**
        * NewLC.
        * Two-phased constructor.
        * Construct a CLogExportDocument for the AVKON application aApp
        * using two phase construction, and return a pointer
        * to the created object.
        * @param aApp Application creating this document.
        * @return A pointer to the created instance of CLogExportDocument.
        */
        static CLogExportDocument* NewLC( CEikApplication& aApp );

        /**
        * ~CLogExportDocument
        * Virtual Destructor.
        */
        virtual ~CLogExportDocument();

    public: // Functions from base classes

        /**
        * CreateAppUiL
        * From CEikDocument, CreateAppUiL.
        * Create a CLogExportAppUi object and return a pointer to it.
        * The object returned is owned by the Uikon framework.
        * @return Pointer to created instance of AppUi.
        */
        CEikAppUi* CreateAppUiL();

    private: // Constructors

        /**
        * ConstructL
        * 2nd phase constructor.
        */
        void ConstructL();

        /**
        * CLogExportDocument.
        * C++ default constructor.
        * @param aApp Application creating this document.
        */
        CLogExportDocument( CEikApplication& aApp );

    };

#endif // __LOGEXPORTDOCUMENT_h__

// End of File
