/*
    LogExport: Export Symbian call log to a file
	Copyright (C) 2007 Yohanes Nugroho

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
/*
============================================================================
 Name        : LogExportAppView.cpp
 Author      : Yohanes Nugroho
 Copyright   : Yohanes Nugroho
 Description : Application view implementation
============================================================================
*/

// INCLUDE FILES
#include <coemain.h>
#include <aknutils.h> 
#include "LogExportAppView.h"

// ============================ MEMBER FUNCTIONS ===============================

// -----------------------------------------------------------------------------
// CLogExportAppView::NewL()
// Two-phased constructor.
// -----------------------------------------------------------------------------
//
CLogExportAppView* CLogExportAppView::NewL( const TRect& aRect )
    {
    CLogExportAppView* self = CLogExportAppView::NewLC( aRect );
    CleanupStack::Pop( self );
    return self;
    }

// -----------------------------------------------------------------------------
// CLogExportAppView::NewLC()
// Two-phased constructor.
// -----------------------------------------------------------------------------
//
CLogExportAppView* CLogExportAppView::NewLC( const TRect& aRect )
    {
    CLogExportAppView* self = new ( ELeave ) CLogExportAppView;
    CleanupStack::PushL( self );
    self->ConstructL( aRect );
    return self;
    }

// -----------------------------------------------------------------------------
// CLogExportAppView::ConstructL()
// Symbian 2nd phase constructor can leave.
// -----------------------------------------------------------------------------
//
void CLogExportAppView::ConstructL( const TRect& aRect )
    {
    // Create a window for this application view
    CreateWindowL();

    // Set the windows size
    SetRect( aRect );
	
    // Activate the window, which makes it ready to be drawn
    ActivateL();
	
	
  	TCharFormat charFormat;
  	TCharFormatMask charFormatMask;
	const CFont* logicalFont = AknLayoutUtils::FontFromId(EAknLogicalFontSecondaryFont);
	TFontSpec fontSpec = logicalFont->FontSpecInTwips();
	charFormat.iFontSpec = fontSpec;
	charFormatMask.SetAttrib(EAttFontTypeface);
	charFormatMask.SetAttrib(EAttFontHeight);
  
  	iParaFormatLayer=CParaFormatLayer::NewL(); // required para format layer
  	iCharFormatLayer=CCharFormatLayer::NewL(charFormat,charFormatMask); // required char format layer
  	iRichText=CRichText::NewL(iParaFormatLayer, iCharFormatLayer);
  	CParaFormat *paraFormat = CParaFormat::NewL();
  	CleanupStack::PushL(paraFormat);
  	TParaFormatMask paraFormatMask;
  	TInt len;
  	TInt pos;
	
  	iRichText->AppendParagraphL(8);
  	paraFormatMask.SetAttrib(EAttAlignment); // interested in alignment
  	paraFormat->iHorizontalAlignment=CParaFormat::ECenterAlign; 

  	pos = iRichText->CharPosOfParagraph(len,0); // get start of first para
  	iRichText->SetInsertCharFormatL(charFormat,charFormatMask,0);
  	iRichText->ApplyParaFormatL(paraFormat,paraFormatMask,pos,1);
  	_LIT(KTitle, "Export Log To CSV v1.1");
	iRichText->InsertL(0, KTitle);

  	charFormatMask.SetAttrib(EAttColor);
  	charFormat.iFontPresentation.iTextColor=TLogicalRgb( TRgb(0,0,255) ) ; //Blue
  	charFormat.iFontSpec.iTypeface.iName = _L("LatinBold12");
  	charFormatMask.SetAttrib(EAttFontTypeface); 
  	iRichText->ApplyCharFormatL(charFormat, charFormatMask, 0, KTitle().Length());
	
	pos = iRichText->CharPosOfParagraph(len, 2);
	
  	_LIT(KTitle2, "Copyright (c) 2006-2007 Yohanes N");
	iRichText->InsertL(pos, KTitle2);

	charFormatMask.ClearAttrib(EAttFontTypeface); 
  	charFormatMask.SetAttrib(EAttColor);
  	charFormat.iFontPresentation.iTextColor=TLogicalRgb( TRgb(0,0,255) ) ; //Blue
  	charFormatMask.SetAttrib(EAttFontUnderline); // interested in underline
  	charFormat.iFontPresentation.iUnderline=EUnderlineOn; // set it on

	pos = iRichText->CharPosOfParagraph(len, 3);
	
  	_LIT(KTitle2x, "A Freeware from:");
	iRichText->InsertL(pos, KTitle2x);
	
	
	pos = iRichText->CharPosOfParagraph(len, 4);
	
	 _LIT(KTitle3, "http://compactbyte.com");
	iRichText->InsertL(pos, KTitle3);

	charFormatMask.ClearAttrib(EAttFontTypeface); 
  	charFormatMask.SetAttrib(EAttColor);
  	charFormat.iFontPresentation.iTextColor=TLogicalRgb( TRgb(0,0,255) ) ; //Blue
  	charFormatMask.SetAttrib(EAttFontUnderline); // interested in underline
  	charFormat.iFontPresentation.iUnderline=EUnderlineOn; // set it on

	iRichText->ApplyCharFormatL(charFormat, charFormatMask, pos, KTitle3().Length());
	iRichText->ApplyParaFormatL(paraFormat,paraFormatMask,pos, KTitle3().Length());
	
	pos = iRichText->CharPosOfParagraph(len, 5);

  	_LIT(KTitle4, "Press Options then Export to export your call log to CSV");
	iRichText->InsertL(pos, KTitle4);
	
	CWindowGc& gc=SystemGc(); // get graphics context
    	CBitmapDevice *device=(CBitmapDevice*) (gc.Device()); // device
    	
	TRect rct = Rect();
	rct.Shrink(2,2);
	
    	iLayout=CTextLayout::NewL(iRichText,rct.Width());
    	// Create text view
    	iTextView=CTextView::NewL(iLayout, rct,
        	device,
        	device,
        	&Window(),
        	0, // no window group
        	&iCoeEnv->WsSession()
        ); // new view
        CleanupStack::PopAndDestroy(paraFormat);
    	iTextView->FormatTextL();
	
    }

// -----------------------------------------------------------------------------
// CLogExportAppView::CLogExportAppView()
// C++ default constructor can NOT contain any code, that might leave.
// -----------------------------------------------------------------------------
//
CLogExportAppView::CLogExportAppView()
    {
    // No implementation required
    }


// -----------------------------------------------------------------------------
// CLogExportAppView::~CLogExportAppView()
// Destructor.
// -----------------------------------------------------------------------------
//
CLogExportAppView::~CLogExportAppView()
    {
    	delete iRichText; 
    	delete iParaFormatLayer;
	delete iCharFormatLayer;
	delete iLayout;
        delete iTextView;
    }


// -----------------------------------------------------------------------------
// CLogExportAppView::Draw()
// Draws the display.
// -----------------------------------------------------------------------------
//
void CLogExportAppView::Draw( const TRect& /*aRect*/ ) const
    {
    // Get the standard graphics context
    CWindowGc& gc = SystemGc();

    // Gets the control's extent
    TRect drawRect( Rect());

    // Clears the screen
    gc.Clear( drawRect );
	
	TRect rct = Rect();
	rct.Shrink(2,2);
	if (iTextView) {
		TRAPD(err,iTextView->DrawL(rct, gc));
	}
	
    
  	}

// -----------------------------------------------------------------------------
// CLogExportAppView::SizeChanged()
// Called by framework when the view size is changed.
// -----------------------------------------------------------------------------
//
void CLogExportAppView::SizeChanged()
    {  
    DrawNow();
    }
// End of File
